# coding: utf-8

"""
    AssistedInstall

    Assisted installation  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class PlatformExternal(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'platform_name': 'str',
        'cloud_controller_manager': 'str'
    }

    attribute_map = {
        'platform_name': 'platform_name',
        'cloud_controller_manager': 'cloud_controller_manager'
    }

    def __init__(self, platform_name=None, cloud_controller_manager=''):  # noqa: E501
        """PlatformExternal - a model defined in Swagger"""  # noqa: E501

        self._platform_name = None
        self._cloud_controller_manager = None
        self.discriminator = None

        if platform_name is not None:
            self.platform_name = platform_name
        if cloud_controller_manager is not None:
            self.cloud_controller_manager = cloud_controller_manager

    @property
    def platform_name(self):
        """Gets the platform_name of this PlatformExternal.  # noqa: E501

        Holds the arbitrary string representing the infrastructure provider name.  # noqa: E501

        :return: The platform_name of this PlatformExternal.  # noqa: E501
        :rtype: str
        """
        return self._platform_name

    @platform_name.setter
    def platform_name(self, platform_name):
        """Sets the platform_name of this PlatformExternal.

        Holds the arbitrary string representing the infrastructure provider name.  # noqa: E501

        :param platform_name: The platform_name of this PlatformExternal.  # noqa: E501
        :type: str
        """
        if platform_name is not None and len(platform_name) < 1:
            raise ValueError("Invalid value for `platform_name`, length must be greater than or equal to `1`")  # noqa: E501

        self._platform_name = platform_name

    @property
    def cloud_controller_manager(self):
        """Gets the cloud_controller_manager of this PlatformExternal.  # noqa: E501

        When set to external, this property will enable an external cloud provider.  # noqa: E501

        :return: The cloud_controller_manager of this PlatformExternal.  # noqa: E501
        :rtype: str
        """
        return self._cloud_controller_manager

    @cloud_controller_manager.setter
    def cloud_controller_manager(self, cloud_controller_manager):
        """Sets the cloud_controller_manager of this PlatformExternal.

        When set to external, this property will enable an external cloud provider.  # noqa: E501

        :param cloud_controller_manager: The cloud_controller_manager of this PlatformExternal.  # noqa: E501
        :type: str
        """
        allowed_values = ["", "External"]  # noqa: E501
        if cloud_controller_manager not in allowed_values:
            raise ValueError(
                "Invalid value for `cloud_controller_manager` ({0}), must be one of {1}"  # noqa: E501
                .format(cloud_controller_manager, allowed_values)
            )

        self._cloud_controller_manager = cloud_controller_manager

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PlatformExternal, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PlatformExternal):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    AssistedInstall

    Assisted installation  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class DiskEncryption(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'enable_on': 'str',
        'mode': 'str',
        'tang_servers': 'str'
    }

    attribute_map = {
        'enable_on': 'enable_on',
        'mode': 'mode',
        'tang_servers': 'tang_servers'
    }

    def __init__(self, enable_on='none', mode='tpmv2', tang_servers=None):  # noqa: E501
        """DiskEncryption - a model defined in Swagger"""  # noqa: E501

        self._enable_on = None
        self._mode = None
        self._tang_servers = None
        self.discriminator = None

        if enable_on is not None:
            self.enable_on = enable_on
        if mode is not None:
            self.mode = mode
        if tang_servers is not None:
            self.tang_servers = tang_servers

    @property
    def enable_on(self):
        """Gets the enable_on of this DiskEncryption.  # noqa: E501

        Enable/disable disk encryption on master nodes, arbiter nodes, worker nodes, or a combination of them.  # noqa: E501

        :return: The enable_on of this DiskEncryption.  # noqa: E501
        :rtype: str
        """
        return self._enable_on

    @enable_on.setter
    def enable_on(self, enable_on):
        """Sets the enable_on of this DiskEncryption.

        Enable/disable disk encryption on master nodes, arbiter nodes, worker nodes, or a combination of them.  # noqa: E501

        :param enable_on: The enable_on of this DiskEncryption.  # noqa: E501
        :type: str
        """
        allowed_values = ["none", "masters", "arbiters", "workers", "masters,arbiters", "masters,workers", "arbiters,workers", "masters,arbiters,workers", "all"]  # noqa: E501
        if enable_on not in allowed_values:
            raise ValueError(
                "Invalid value for `enable_on` ({0}), must be one of {1}"  # noqa: E501
                .format(enable_on, allowed_values)
            )

        self._enable_on = enable_on

    @property
    def mode(self):
        """Gets the mode of this DiskEncryption.  # noqa: E501

        The disk encryption mode to use.  # noqa: E501

        :return: The mode of this DiskEncryption.  # noqa: E501
        :rtype: str
        """
        return self._mode

    @mode.setter
    def mode(self, mode):
        """Sets the mode of this DiskEncryption.

        The disk encryption mode to use.  # noqa: E501

        :param mode: The mode of this DiskEncryption.  # noqa: E501
        :type: str
        """
        allowed_values = ["tpmv2", "tang"]  # noqa: E501
        if mode not in allowed_values:
            raise ValueError(
                "Invalid value for `mode` ({0}), must be one of {1}"  # noqa: E501
                .format(mode, allowed_values)
            )

        self._mode = mode

    @property
    def tang_servers(self):
        """Gets the tang_servers of this DiskEncryption.  # noqa: E501

        JSON-formatted string containing additional information regarding tang's configuration  # noqa: E501

        :return: The tang_servers of this DiskEncryption.  # noqa: E501
        :rtype: str
        """
        return self._tang_servers

    @tang_servers.setter
    def tang_servers(self, tang_servers):
        """Sets the tang_servers of this DiskEncryption.

        JSON-formatted string containing additional information regarding tang's configuration  # noqa: E501

        :param tang_servers: The tang_servers of this DiskEncryption.  # noqa: E501
        :type: str
        """

        self._tang_servers = tang_servers

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DiskEncryption, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DiskEncryption):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    AssistedInstall

    Assisted installation  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class LoadBalancer(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str'
    }

    attribute_map = {
        'type': 'type'
    }

    def __init__(self, type=None):  # noqa: E501
        """LoadBalancer - a model defined in Swagger"""  # noqa: E501

        self._type = None
        self.discriminator = None

        if type is not None:
            self.type = type

    @property
    def type(self):
        """Gets the type of this LoadBalancer.  # noqa: E501

        Indicates if the load balancer will be managed by the cluster or by the user. This is optional and The default is `cluster-managed`.  `cluster-managed` means that the cluster will start the components that assign the API and ingress VIPs to the nodes of the cluster automatically.  `user-managed` means that the user is responsible for configuring an external load balancer and assign the API and ingress VIPs to it. Note that this configuration needs to be completed before starting the installation of the cluster, as it is needed during the installation process.   # noqa: E501

        :return: The type of this LoadBalancer.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this LoadBalancer.

        Indicates if the load balancer will be managed by the cluster or by the user. This is optional and The default is `cluster-managed`.  `cluster-managed` means that the cluster will start the components that assign the API and ingress VIPs to the nodes of the cluster automatically.  `user-managed` means that the user is responsible for configuring an external load balancer and assign the API and ingress VIPs to it. Note that this configuration needs to be completed before starting the installation of the cluster, as it is needed during the installation process.   # noqa: E501

        :param type: The type of this LoadBalancer.  # noqa: E501
        :type: str
        """
        allowed_values = ["cluster-managed", "user-managed"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LoadBalancer, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LoadBalancer):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
